//
//  ViewController.m
//  TXCPlayerAdapterDemo
//
//  Created by chavezchen on 2021/3/10.
//

#import "ViewController.h"
#import <TXCPlayerAdapter/TXCPlayerAdapter.h>
#import <TXCPlayerAdapter/TXCVideoBasicInfo.h>
#import <AVFoundation/AVFoundation.h>
#import <AVKit/AVKit.h>
#import "UIView+Toast.h"

// 是否播放加密视频 0是不加密 1是加密
#define PLAY_ENCRYPTION_VIDEO 1

@interface ViewController ()
@property (weak, nonatomic) IBOutlet UITextField *appIdTextFiled;
@property (weak, nonatomic) IBOutlet UITextField *fileIdTextFiled;
@property (weak, nonatomic) IBOutlet UITextView *pSignTextView;
@property (nonatomic, weak) UIView *contentView;
@property (nonatomic, weak) AVPlayerViewController *playerVC;
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.pSignTextView.layer.borderColor = [UIColor lightGrayColor].CGColor;
    self.pSignTextView.layer.borderWidth = 1.0f;
    self.pSignTextView.layer.cornerRadius = 2;
    self.appIdTextFiled.text = @"1254432039";
    self.fileIdTextFiled.text = @"5285890816303742312";
    
    /*
     appId: 1254432039
     加密视频 fileId: 5285890815576293752
     pSign: @"eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcHBJZCI6MTI1NDQzMjAzOSwiZmlsZUlkIjoiNTI4NTg5MDgxNTU3NjI5Mzc1MiIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MTYwMzQ2NDAsImV4cGlyZVRpbWVTdGFtcCI6MTY0MDAzNDY0MCwicGNmZyI6ImJhc2ljRHJtUHJlc2V0IiwidXJsQWNjZXNzSW5mbyI6e30sImRybUxpY2Vuc2VJbmZvIjp7ImV4cGlyZVRpbWVTdGFtcCI6MTY0MDAzNDY0MH19.wI7ETGZ04piZZqtTkxuGgZukrILMuAIfIS9eJgEYP6Q"
     
     李永乐加密视频 fileId: 5285890816303742312
     pSign: @"eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcHBJZCI6MTI1NDQzMjAzOSwiZmlsZUlkIjoiNTI4NTg5MDgxNjMwMzc0MjMxMiIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MTcyNTc0ODMsInBjZmciOiJiYXNpY0RybVByZXNldCIsInVybEFjY2Vzc0luZm8iOnt9LCJkcm1MaWNlbnNlSW5mbyI6e319.2H1t9dKPpdA41a8t1WwI631OWC18HGl60ccBDLylCKE"
     */

#if PLAY_ENCRYPTION_VIDEO
    // 加密视频
    self.pSignTextView.text = @"eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcHBJZCI6MTI1NDQzMjAzOSwiZmlsZUlkIjoiNTI4NTg5MDgxNjMwMzc0MjMxMiIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MTcyNTc0ODMsInBjZmciOiJiYXNpY0RybVByZXNldCIsInVybEFjY2Vzc0luZm8iOnt9LCJkcm1MaWNlbnNlSW5mbyI6e319.2H1t9dKPpdA41a8t1WwI631OWC18HGl60ccBDLylCKE";
#else
//    self.fileIdTextFiled.text = @"5285890815576293752";
    // 未加密视频
    self.pSignTextView.text = @"eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcHBJZCI6MTI1NDQzMjAzOSwiZmlsZUlkIjoiNTI4NTg5MDgxNjMwMzc0MjMxMiIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MTcyNTc0ODMsInBjZmciOiJkZWZhdWx0IiwidXJsQWNjZXNzSW5mbyI6e30sImRybUxpY2Vuc2VJbmZvIjp7fX0.xTlKpFUpeZ5kvflCvK93mol-sMlZkZHlSk-TcXzJD0g";
#endif
    
       
}

- (void)avplayerPlay:(id<ITXCPlayerAssistorProtocol>)response
{
    AVPlayerViewController *playerVC = [[AVPlayerViewController alloc] init];
    self.playerVC = playerVC;
    TXCStreamingInfo *info = response.getStreamingInfo;
    AVPlayer *player = [[AVPlayer alloc] initWithURL:[NSURL URLWithString:info.playUrl]];
    playerVC.player = player;
    playerVC.title = response.getVideoBasicInfo.name;
    [self.navigationController pushViewController:playerVC animated:YES];
    
    [player addObserver:self forKeyPath:@"status" options:NSKeyValueObservingOptionNew context:nil];
}

- (IBAction)playAction:(UIButton *)sender
{
    [self.view endEditing:YES];
    [self play];
}

- (void)play
{
    NSInteger appId = self.appIdTextFiled.text.integerValue;
    NSString *fileId = self.fileIdTextFiled.text;
    NSString *pSign = self.pSignTextView.text;
    
    TXCPlayerAdapter *adapter = [TXCPlayerAdapter shareAdapterWithAppId:appId];
    if (adapter == nil) {
        [self.view makeToast:@"请输入合法的appId！！！" duration:5.0 position:CSToastPositionBottom];
    }

    __weak typeof(self) weakSelf = self;
    id<ITXCPlayerAssistorProtocol> assistor = [TXCPlayerAdapter createPlayerAssistorWithFileId:fileId pSign:pSign];
    [assistor requestVideoInfo:^(id<ITXCPlayerAssistorProtocol> response, NSError *error) {
        if (error) {
            NSLog(@"create player assistor error : %@",error);
            [self.view makeToast:error.description duration:5.0 position:CSToastPositionBottom];
            return;
        }
        [weakSelf avplayerPlay:response];
    }];
    
}

- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event
{
    [self.view endEditing:YES];
}

#pragma mark - kvo
- (void)observeValueForKeyPath:(NSString *)keyPath ofObject:(id)object change:(NSDictionary<NSKeyValueChangeKey,id> *)change context:(void *)context
{
    NSInteger status = [[change valueForKey:NSKeyValueChangeNewKey] integerValue];
    if (status == AVPlayerStatusReadyToPlay) {
        [self.playerVC.player play];
    }
}

#pragma mark 支持横屏
- (BOOL)shouldAutorotate {
      return YES;
}

//2.返回支持的旋转方向
- (UIInterfaceOrientationMask)supportedInterfaceOrientations{
     return UIInterfaceOrientationMaskAll;
}

//3.返回进入界面默认显示方向
- (UIInterfaceOrientation)preferredInterfaceOrientationForPresentation {
     return UIInterfaceOrientationPortrait;
}


@end
